@@ -1,5 +1,5 @@
 package AnyEvent::SlackRTM;
-$AnyEvent::SlackRTM::VERSION = '0.151570';
+$AnyEvent::SlackRTM::VERSION = '0.151800';
 use v5.14;
 
 # ABSTRACT: AnyEvent module for interacting with the Slack RTM API
@@ -129,7 +129,7 @@ sub ping {
     my ($self, $msg) = @_;
 
     $self->send({ 
-        %$msg,
+        %{ $msg // {} },
         type => 'ping' 
     });
 }
@@ -212,7 +212,7 @@ AnyEvent::SlackRTM - AnyEvent module for interacting with the Slack RTM API
 
 =head1 VERSION
 
-version 0.151570
+version 0.151800
 
 =head1 SYNOPSIS
 
